pub trait Config: Config + Config { }Expand description
Configuration trait of this pezpallet.
The main purpose of this trait is to act as an interface between this pezpallet and the runtime in which it is embedded in. A type, function, or constant in this trait is essentially left to be configured by the runtime that includes this pezpallet.
Consequently, a runtime that wants to include this pezpallet must implement this trait.
This pezpallet can only live in a runtime that has both pezframe_system and
pezpallet_author.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.